pub enum ObservationDraftCommands {
List {
limit: Option<i64>,
},
Show {
id: Uuid,
},
Promote(ObservationDraftPromoteArgs),
Resolve(ObservationDraftResolveArgs),
Dismiss(ObservationDraftDismissArgs),
}Variants
List
List open persist-intent drafts
Show
Show one draft observation in detail
Promote(ObservationDraftPromoteArgs)
Promote draft into a formal event and retract the draft
Resolve(ObservationDraftResolveArgs)
Resolve draft as durable observation and retract the draft
Dismiss(ObservationDraftDismissArgs)
Dismiss non-actionable draft and retract it