pub enum AdminCommands {
CreateUser {
email: String,
password: String,
display_name: Option<String>,
},
CreateKey {
user_id: String,
label: String,
expires_in_days: Option<i64>,
},
DeleteUser {
user_id: String,
confirm: bool,
},
ListRequests {
status: String,
},
ApproveRequest {
id: String,
},
RejectRequest {
id: String,
},
CreateInvite {
email: Option<String>,
expires_in_days: i64,
},
ListInvites {
status: Option<String>,
},
SupportReidentify {
user_id: String,
reason: String,
ticket_id: String,
requested_mode: Option<String>,
expires_at: Option<String>,
},
Telemetry {
command: AdminTelemetryCommands,
},
}Variants
CreateUser
Create a new user (requires DATABASE_URL)
Fields
CreateKey
Create an API key for a user (requires DATABASE_URL)
Fields
DeleteUser
Permanently delete a user and all their data (admin only, via API)
ListRequests
List access requests (admin only, via API)
ApproveRequest
Approve an access request and generate invite token (admin only, via API)
RejectRequest
Reject an access request (admin only, via API)
CreateInvite
Create a manual invite token (admin only, via API)
Fields
ListInvites
List invite tokens (admin only, via API)
SupportReidentify
Audited break-glass identity lookup by user UUID (admin only)
Fields
Telemetry
Agent telemetry endpoints (admin only, via API)
Fields

command: AdminTelemetryCommandsTrait Implementations
Sourceimpl FromArgMatches for AdminCommands
impl FromArgMatches for AdminCommands
Sourcefn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
fn from_arg_matches(__clap_arg_matches: &ArgMatches) -> Result<Self, Error>
Sourcefn from_arg_matches_mut(
__clap_arg_matches: &mut ArgMatches,
) -> Result<Self, Error>
fn from_arg_matches_mut( __clap_arg_matches: &mut ArgMatches, ) -> Result<Self, Error>
Sourcefn update_from_arg_matches(
&mut self,
__clap_arg_matches: &ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches( &mut self, __clap_arg_matches: &ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourcefn update_from_arg_matches_mut<'b>(
&mut self,
__clap_arg_matches: &mut ArgMatches,
) -> Result<(), Error>
fn update_from_arg_matches_mut<'b>( &mut self, __clap_arg_matches: &mut ArgMatches, ) -> Result<(), Error>
Assign values from
ArgMatches to self.Sourceimpl Subcommand for AdminCommands
impl Subcommand for AdminCommands
Sourcefn augment_subcommands<'b>(__clap_app: Command) -> Command
fn augment_subcommands<'b>(__clap_app: Command) -> Command
Sourcefn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
fn augment_subcommands_for_update<'b>(__clap_app: Command) -> Command
Append to
Command so it can instantiate self via
FromArgMatches::update_from_arg_matches_mut Read moreSourcefn has_subcommand(__clap_name: &str) -> bool
fn has_subcommand(__clap_name: &str) -> bool
Test whether
Self can parse a specific subcommandAuto Trait Implementations
impl Freeze for AdminCommands
impl RefUnwindSafe for AdminCommands
impl Send for AdminCommands
impl Sync for AdminCommands
impl Unpin for AdminCommands
impl UnsafeUnpin for AdminCommands
impl UnwindSafe for AdminCommands